@@ -1,5 +1,5 @@
 /*
- * PC/HW routine collection v1.1 for DOS/DJGPP
+ * PC/HW routine collection v1.3 for DOS/DJGPP
  *
  *  Copyright (C) 2002 - Borca Daniel
  *  Email : dborca@yahoo.com
@@ -357,20 +357,6 @@ static void handle_code (int scancode, int keycode)
  in_a_terrupt--;
 } ENDOFUNC(handle_code)
 
-static __inline void satisfy (void)
-{
- __asm("\n\
-		inb	$0x61, %%al	\n\
-		movb	%%al, %%ah	\n\
-		orb	$0x80, %%al	\n\
-		outb	%%al, $0x61	\n\
-		xchgb	%%al, %%ah	\n\
-		outb	%%al, $0x61	\n\
-		movb	$0x20, %%al	\n\
-		outb	%%al, $0x20	\n\
- ":::"%eax");
-}
-
 static int keyboard ()
 {
  unsigned char temp, scancode;
@@ -410,7 +396,16 @@ static int keyboard ()
     ":::"%eax", "%ebx", "%ecx", "%edx", "%esi", "%edi", "memory");
  }
 
- satisfy();
+ __asm("\n\
+		inb	$0x61, %%al	\n\
+		movb	%%al, %%ah	\n\
+		orb	$0x80, %%al	\n\
+		outb	%%al, $0x61	\n\
+		xchgb	%%al, %%ah	\n\
+		outb	%%al, $0x61	\n\
+		movb	$0x20, %%al	\n\
+		outb	%%al, $0x20	\n\
+ ":::"%eax");
  return 0;
 } ENDOFUNC(keyboard)
 
@@ -425,8 +420,9 @@ int pc_readkey (void)
  if (keyboard_installed) {
     int key;
 
-    do {
-    } while (key_buffer.start==key_buffer.end);
+    while (key_buffer.start==key_buffer.end) {
+          __dpmi_yield();
+    }
 
     DISABLE();
     key = key_buffer.key[key_buffer.start++];
@@ -445,6 +441,11 @@ int pc_keydown (int code)
  return pc_key[code];
 }
 
+int pc_keyshifts (void)
+{
+ return key_shifts;
+}
+
 void pc_remove_keyb (void)
 {
  if (keyboard_installed) {
